==> chgk_rating-0.0.1.tar.gz: lib/src/models/tournament_controversial.dart <==
/// Response example:
/// [
/// {
///     "question_number": "6",
///     "answer": "Росвелл",
///     "issued_at": "2017-07-19 17:28:11",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:04",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "12",
///     "answer": "Альбрехт Альбрунер",
///     "issued_at": "2017-07-19 17:28:11",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:10",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "14",
///     "answer": "картофель",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "D",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:16",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "14",
///     "answer": "картофель",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "D",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:16",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "14",
///     "answer": "картофель",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "D",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:16",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "14",
///     "answer": "картофель",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "D",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:16",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "14",
///     "answer": "картофель",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "D",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:16",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "14",
///     "answer": "картошка",
///     "issued_at": "2017-07-19 17:28:11",
///     "status": "D",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:20",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "15",
///     "answer": "Осанна",
///     "issued_at": "2017-07-19 08:19:43",
///     "status": "D",
///     "comment": "",
///     "resolved_at": "2017-07-25 09:56:53",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "17",
///     "answer": "конденсат",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:57:22",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "17",
///     "answer": "конденсат",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:57:22",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "17",
///     "answer": "конденсат",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:57:22",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "17",
///     "answer": "конденсат",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:57:22",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "17",
///     "answer": "водяной пар",
///     "issued_at": "2017-07-19 17:28:11",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:57:14",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "22",
///     "answer": "Нотр-Дам",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 14:23:18",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "22",
///     "answer": "Собор Парижской Богоматери",
///     "issued_at": "2017-07-19 08:15:05",
///     "status": "A",
///     "comment": "",
///     "resolved_at": "2017-07-25 14:23:14",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "25",
///     "answer": "копьё власти",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:53:02",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "30",
///     "answer": "германские гетто",
///     "issued_at": "2017-07-18 22:33:57",
///     "status": "D",
///     "comment": "",
///     "resolved_at": "2017-07-25 14:23:23",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "30",
///     "answer": "городские гетто",
///     "issued_at": "2017-07-20 12:17:45",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 13:19:16",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "33",
///     "answer": "теплое течение",
///     "issued_at": "2017-07-19 17:28:11",
///     "status": "D",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:57:30",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "34",
///     "answer": "пчих",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 14:23:09",
///     "appeal_jury_comment": null
/// },
/// {
///     "question_number": "34",
///     "answer": "факультет Пчхи",
///     "issued_at": "2017-07-15 12:01:14",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:53:12",
///     "appeal_jury_comment": null
/// }
/// ]
import 'dart:convert';

class TournamentControversial {
  TournamentControversial({
    this.questionNumber,
    this.answer,
    this.issuedAt,
    this.status,
    this.comment,
    this.resolvedAt,
    this.appealJuryComment,
  });

  final String? questionNumber;
  final String? answer;
  final DateTime? issuedAt;
  final QuestionStatus? status;
  final String? comment;
  final DateTime? resolvedAt;
  final String? appealJuryComment;

  factory TournamentControversial.fromJson(String str) =>
      TournamentControversial.fromMap(json.decode(str));

  String toJson() => json.encode(toMap());

  factory TournamentControversial.fromMap(Map<String, dynamic> json) =>
      TournamentControversial(
        questionNumber:
            json['question_number'] == null ? null : json['question_number'],
        answer: json['answer'] == null ? null : json['answer'],
        issuedAt: json['issued_at'] == null
            ? null
            : DateTime.parse(json['issued_at']),
        status:
            json['status'] == null ? null : statusValues.map[json['status']],
        comment: json['comment'] == null ? null : json['comment'],
        resolvedAt: json['resolved_at'] == null
            ? null
            : DateTime.parse(json['resolved_at']),
        appealJuryComment: json['appeal_jury_comment'] == null
            ? null
            : json['appeal_jury_comment'],
      );

  Map<String, dynamic> toMap() => {
        'question_number': questionNumber == null ? null : questionNumber,
        'answer': answer == null ? null : answer,
        'issued_at': issuedAt == null ? null : issuedAt?.toIso8601String(),
        'status': status == null ? null : statusValues.reverse[status],
        'comment': comment == null ? null : comment,
        'resolved_at':
            resolvedAt == null ? null : resolvedAt?.toIso8601String(),
        'appeal_jury_comment':
            appealJuryComment == null ? null : appealJuryComment,
      };
}

enum QuestionStatus { A, D, N }

final EnumValues<QuestionStatus> statusValues = EnumValues<QuestionStatus>(
    {'A': QuestionStatus.A, 'D': QuestionStatus.D, 'N': QuestionStatus.N});

class EnumValues<T> {
  Map<String, T> map;
  Map<T, String>? reverseMap;

  EnumValues(this.map);

  Map<T, String> get reverse {
    reverseMap ??= map.map((String k, v) => MapEntry(v, k));
    return reverseMap!;
  }
}

==> chgk_rating-0.0.3.tar.gz: lib/src/models/tournament_controversial.dart <==
import 'dart:convert';

/// Response example:
/// ```json
/// [
/// {
///     "question_number": "6",
///     "answer": "Росвелл",
///     "issued_at": "2017-07-19 17:28:11",
///     "status": "A",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:52:04",
///     "appeal_jury_comment": "Комментарий"
/// },
/// {
///     "question_number": "33",
///     "answer": "теплое течение",
///     "issued_at": "2017-07-19 17:28:11",
///     "status": "D",
///     "comment": null,
///     "resolved_at": "2017-07-25 09:57:30",
///     "appeal_jury_comment": "Комментарий"
/// }
/// ]
/// ```
class TournamentControversial {
  TournamentControversial({
    this.questionNumber,
    this.answer,
    this.issuedAt,
    this.status,
    this.comment,
    this.resolvedAt,
    this.appealJuryComment,
  });

  final String? questionNumber;
  final String? answer;
  final DateTime? issuedAt;
  final QuestionStatus? status;
  final String? comment;
  final DateTime? resolvedAt;
  final String? appealJuryComment;

  /// Decodes [TournamentControversial] object from json string
  factory TournamentControversial.fromJson(String str) =>
      TournamentControversial.fromMap(json.decode(str));

  /// Encodes [TournamentControversial] object to json string
  String toJson() => json.encode(toMap());

  /// Decodes [TournamentControversial] object from json map
  factory TournamentControversial.fromMap(Map<String, dynamic> json) =>
      TournamentControversial(
        questionNumber:
            json['question_number'] == null ? null : json['question_number'],
        answer: json['answer'] == null ? null : json['answer'],
        issuedAt: json['issued_at'] == null
            ? null
            : DateTime.parse(json['issued_at']),
        status:
            json['status'] == null ? null : statusValues.map[json['status']],
        comment: json['comment'] == null ? null : json['comment'],
        resolvedAt: json['resolved_at'] == null
            ? null
            : DateTime.parse(json['resolved_at']),
        appealJuryComment: json['appeal_jury_comment'] == null
            ? null
            : json['appeal_jury_comment'],
      );

  /// Encodes [TournamentControversial] object to json map
  Map<String, dynamic> toMap() => {
        'question_number': questionNumber == null ? null : questionNumber,
        'answer': answer == null ? null : answer,
        'issued_at': issuedAt == null ? null : issuedAt?.toIso8601String(),
        'status': status == null ? null : statusValues.reverse[status],
        'comment': comment == null ? null : comment,
        'resolved_at':
            resolvedAt == null ? null : resolvedAt?.toIso8601String(),
        'appeal_jury_comment':
            appealJuryComment == null ? null : appealJuryComment,
      };

  @override
  String toString() {
    return 'TournamentControversial{questionNumber: $questionNumber, answer: $answer, issuedAt: $issuedAt, status: $status, comment: $comment, resolvedAt: $resolvedAt, appealJuryComment: $appealJuryComment}';
  }
}

/// [A] - approved, [D] - declined, [N] - new
enum QuestionStatus { A, D, N }

/// [QuestionStatus.A] - approved, [QuestionStatus.D] - declined, [QuestionStatus.N] - new
final EnumValues<QuestionStatus> statusValues = EnumValues<QuestionStatus>(
    {'A': QuestionStatus.A, 'D': QuestionStatus.D, 'N': QuestionStatus.N});

class EnumValues<T> {
  Map<String, T> map;
  Map<T, String>? reverseMap;

  EnumValues(this.map);

  Map<T, String> get reverse {
    reverseMap ??= map.map((String k, v) => MapEntry(v, k));
    return reverseMap!;
  }
}
